@@ -20,7 +20,8 @@
 // pizza details:
 // - cheese
 
-const commander = require('../');
+// const commander = require('commander'); // (normal include)
+const commander = require('../'); // include commander in git clone of commander repo
 const program = new commander.Command();
 
 program
