@@ -11,7 +11,8 @@
 // $ pizza-options --cheese stilton
 // cheese: stilton
 
-const commander = require('../');
+// const commander = require('commander'); // (normal include)
+const commander = require('../'); // include commander in git clone of commander repo
 const program = new commander.Command();
 
 program
