@@ -22,8 +22,9 @@ const program = new commander.Command();
 program
   .option('--no-sauce', 'Remove sauce')
   .option('--cheese <flavour>', 'cheese flavour', 'mozzarella')
-  .option('--no-cheese', 'plain with no cheese')
-  .parse(process.argv);
+  .option('--no-cheese', 'plain with no cheese');
+
+program.parse(process.argv);
 
 const sauceStr = program.sauce ? 'sauce' : 'no sauce';
 const cheeseStr = (program.cheese === false) ? 'no cheese' : `${program.cheese} cheese`;
