@@ -20,7 +20,7 @@ test('when .action called then program.args only contains args', () => {
     .command('info <file>')
     .action(() => {});
   program.parse(['node', 'test', 'info', 'my-file']);
-  expect(program.args).toEqual(['my-file']);
+  expect(program.args).toEqual(['info', 'my-file']);
 });
 
 test('when .action called with extra arguments then extras also passed to action', () => {
@@ -35,7 +35,7 @@ test('when .action called with extra arguments then extras also passed to action
   expect(actionMock).toHaveBeenCalledWith('my-file', cmd, ['a']);
 });
 
-test('when .action on program with argument then action called', () => {
+test('when .action on program with required argument and argument supplied then action called', () => {
   const actionMock = jest.fn();
   const program = new commander.Command();
   program
@@ -45,6 +45,22 @@ test('when .action on program with argument then action called', () => {
   expect(actionMock).toHaveBeenCalledWith('my-file', program);
 });
 
+test('when .action on program with required argument and argument not supplied then action not called', () => {
+  // Optional. Use internal knowledge to suppress output to keep test output clean.
+  const consoleErrorSpy = jest.spyOn(console, 'error').mockImplementation(() => { });
+  const actionMock = jest.fn();
+  const program = new commander.Command();
+  program
+    .exitOverride()
+    .arguments('<file>')
+    .action(actionMock);
+  expect(() => {
+    program.parse(['node', 'test']);
+  }).toThrow();
+  expect(actionMock).not.toHaveBeenCalled();
+  consoleErrorSpy.mockRestore();
+});
+
 // Changes made in #729 to call program action handler
 test('when .action on program and no arguments then action called', () => {
   const actionMock = jest.fn();
@@ -75,7 +91,7 @@ test('when .action on program without optional argument supplied then action cal
   expect(actionMock).toHaveBeenCalledWith(undefined, program);
 });
 
-test('when .action on program with subcommand and program argument then program action called', () => {
+test('when .action on program with optional argument and subcommand and program argument then program action called', () => {
   const actionMock = jest.fn();
   const program = new commander.Command();
   program
@@ -89,6 +105,21 @@ test('when .action on program with subcommand and program argument then program
   expect(actionMock).toHaveBeenCalledWith('a', program);
 });
 
+// Changes made in #1062 to allow this case
+test('when .action on program with optional argument and subcommand and no program argument then program action called', () => {
+  const actionMock = jest.fn();
+  const program = new commander.Command();
+  program
+    .arguments('[file]')
+    .action(actionMock);
+  program
+    .command('subcommand');
+
+  program.parse(['node', 'test']);
+
+  expect(actionMock).toHaveBeenCalledWith(undefined, program);
+});
+
 test('when action is async then can await parseAsync', async() => {
   let asyncFinished = false;
   async function delay() {
