@@ -1,22 +1,23 @@
 const commander = require('../');
 
 // Test auto wrap and indent with some manual strings.
+// Fragile tests with complete help output.
 
 test('when long option description then wrap and indent', () => {
   const oldColumns = process.stdout.columns;
   process.stdout.columns = 80;
   const program = new commander.Command();
   program
-    .option('-x -extra-long-option-switch', 'kjsahdkajshkahd kajhsd akhds kashd kajhs dkha dkh aksd ka dkha kdh kasd ka kahs dkh sdkh askdh aksd kashdk ahsd kahs dkha skdh');
+    .option('-x --extra-long-option-switch', 'kjsahdkajshkahd kajhsd akhds kashd kajhs dkha dkh aksd ka dkha kdh kasd ka kahs dkh sdkh askdh aksd kashdk ahsd kahs dkha skdh');
 
   const expectedOutput =
 `Usage:  [options]
 
 Options:
-  -x -extra-long-option-switch  kjsahdkajshkahd kajhsd akhds kashd kajhs dkha
-                                dkh aksd ka dkha kdh kasd ka kahs dkh sdkh
-                                askdh aksd kashdk ahsd kahs dkha skdh
-  -h, --help                    output usage information
+  -x --extra-long-option-switch  kjsahdkajshkahd kajhsd akhds kashd kajhs dkha
+                                 dkh aksd ka dkha kdh kasd ka kahs dkh sdkh
+                                 askdh aksd kashdk ahsd kahs dkha skdh
+  -h, --help                     display help for command
 `;
 
   expect(program.helpInformation()).toBe(expectedOutput);
@@ -28,15 +29,15 @@ test('when long option description and default then wrap and indent', () => {
   process.stdout.columns = 80;
   const program = new commander.Command();
   program
-    .option('-x -extra-long-option <value>', 'kjsahdkajshkahd kajhsd akhds', 'aaa bbb ccc ddd eee fff ggg');
+    .option('-x --extra-long-option <value>', 'kjsahdkajshkahd kajhsd akhds', 'aaa bbb ccc ddd eee fff ggg');
 
   const expectedOutput =
 `Usage:  [options]
 
 Options:
-  -x -extra-long-option <value>  kjsahdkajshkahd kajhsd akhds (default: "aaa
-                                 bbb ccc ddd eee fff ggg")
-  -h, --help                     output usage information
+  -x --extra-long-option <value>  kjsahdkajshkahd kajhsd akhds (default: "aaa
+                                  bbb ccc ddd eee fff ggg")
+  -h, --help                      display help for command
 `;
 
   expect(program.helpInformation()).toBe(expectedOutput);
@@ -48,19 +49,20 @@ test('when long command description then wrap and indent', () => {
   process.stdout.columns = 80;
   const program = new commander.Command();
   program
-    .option('-x -extra-long-option-switch', 'x')
+    .option('-x --extra-long-option-switch', 'x')
     .command('alpha', 'Lorem mollit quis dolor ex do eu quis ad insa a commodo esse.');
 
   const expectedOutput =
 `Usage:  [options] [command]
 
 Options:
-  -x -extra-long-option-switch  x
-  -h, --help                    output usage information
+  -x --extra-long-option-switch  x
+  -h, --help                     display help for command
 
 Commands:
-  alpha                         Lorem mollit quis dolor ex do eu quis ad insa
-                                a commodo esse.
+  alpha                          Lorem mollit quis dolor ex do eu quis ad
+                                 insa a commodo esse.
+  help [command]                 display help for command
 `;
 
   expect(program.helpInformation()).toBe(expectedOutput);
@@ -80,10 +82,11 @@ test('when not enough room then help not wrapped', () => {
 `Usage:  [options] [command]
 
 Options:
-  -h, --help            output usage information
+  -h, --help            display help for command
 
 Commands:
   1234567801234567890x  ${commandDescription}
+  help [command]        display help for command
 `;
 
   expect(program.helpInformation()).toBe(expectedOutput);
@@ -112,7 +115,7 @@ Options:
   Time can also be specified using special values:
     "dawn" - From night to sunrise.
   
-  -h, --help          output usage information
+  -h, --help          display help for command
 `;
 
   expect(program.helpInformation()).toBe(expectedOutput);
